@@ -587,7 +587,7 @@ func TestDeleteBulkSizeTracking(t *testing.T) {
 	require.NoError(t, err)
 
 	deleteParams := &elastic.DeleteParams{
-		Index:   configMap["index_name"].(string),
+		Index:   client.IndexNameDefault,
 		Routing: projectIDString,
 		DocId:   projectIDString + "_test_1",
 	}
@@ -598,7 +598,7 @@ func TestDeleteBulkSizeTracking(t *testing.T) {
 	initialSize := client.CurrentBatchSize()
 
 	deleteParams2 := &elastic.DeleteParams{
-		Index:   configMap["index_name"].(string),
+		Index:   client.IndexNameDefault,
 		Routing: projectIDString,
 		DocId:   projectIDString + "_test_2",
 	}
@@ -641,7 +641,7 @@ func TestMixedOperationsBulkSizeTracking(t *testing.T) {
 	require.Greater(t, size2, size1)
 
 	deleteParams := &elastic.DeleteParams{
-		Index:   configMap["index_name"].(string),
+		Index:   client.IndexNameDefault,
 		Routing: projectIDString,
 		DocId:   projectIDString + "_test_2",
 	}
