@@ -11,8 +11,9 @@ import (
 	"gitlab.com/gitlab-org/gitlab-elasticsearch-indexer/internal/mode/chunk/chunker"
 	codeChunker "gitlab.com/gitlab-org/gitlab-elasticsearch-indexer/internal/mode/chunk/chunker/code"
 	"gitlab.com/gitlab-org/gitlab-elasticsearch-indexer/internal/mode/chunk/client/elasticsearch"
+	"gitlab.com/gitlab-org/gitlab-elasticsearch-indexer/internal/mode/chunk/client/opensearch"
 	"gitlab.com/gitlab-org/gitlab-elasticsearch-indexer/internal/mode/chunk/indexer"
-	elasticsearchIndexer "gitlab.com/gitlab-org/gitlab-elasticsearch-indexer/internal/mode/chunk/indexer/elasticsearch"
+	elasticIndexer "gitlab.com/gitlab-org/gitlab-elasticsearch-indexer/internal/mode/chunk/indexer/elasticsearch"
 	"gitlab.com/gitlab-org/gitlab-elasticsearch-indexer/internal/mode/chunk/streamer"
 	"gitlab.com/gitlab-org/gitlab-elasticsearch-indexer/internal/mode/chunk/types"
 	"gitlab.com/gitlab-org/gitlab-elasticsearch-indexer/internal/shared"
@@ -82,28 +83,37 @@ func createVectorStoreIndexer(ctx context.Context, conn types.Connection, option
 
 	switch conn.GetAdapterType() {
 	case types.ElasticsearchAdapter:
-		esConn := conn.(types.ElasticsearchConnection)
-		esClient := elasticsearch.New(esConn)
+		client := elasticsearch.New(conn.(types.ElasticsearchConnection))
 
-		if err := esClient.Connect(ctx); err != nil {
+		if err := client.Connect(ctx); err != nil {
 			return nil, fmt.Errorf("failed to connect to elasticsearch: %w", err)
 		}
 
 		indexName := fmt.Sprintf("%s_%d", options.PartitionName, options.PartitionNumber)
 
-		indexingStrategy, err = elasticsearchIndexer.New(esClient, indexName, int(options.ElasticBulkSize), options.ForceReindex)
+		indexingStrategy, err = elasticIndexer.New(client, indexName, int(options.ElasticBulkSize), options.ForceReindex)
 		if err != nil {
 			return nil, fmt.Errorf("failed to create elasticsearch indexer: %w", err)
 		}
 
+	case types.OpenSearchAdapter:
+		client := opensearch.New(conn.(types.OpenSearchConnection))
+
+		if err := client.Connect(ctx); err != nil {
+			return nil, fmt.Errorf("failed to connect to opensearch: %w", err)
+		}
+
+		indexName := fmt.Sprintf("%s_%d", options.PartitionName, options.PartitionNumber)
+
+		indexingStrategy, err = elasticIndexer.New(client, indexName, int(options.ElasticBulkSize), options.ForceReindex)
+		if err != nil {
+			return nil, fmt.Errorf("failed to create opensearch indexer: %w", err)
+		}
+
 	case types.PostgreSQLAdapter:
 		// TODO: Implement PostgreSQL indexing strategy https://gitlab.com/gitlab-org/gitlab/-/issues/545483
 		return nil, fmt.Errorf("indexing not implemented for adapter: %s", conn.GetAdapterType())
 
-	case types.OpenSearchAdapter:
-		// TODO: Implement OpenSearch indexing strategy https://gitlab.com/gitlab-org/gitlab/-/issues/545483
-		return nil, fmt.Errorf("indexing not implemented for adapter: %s", conn.GetAdapterType())
-
 	default:
 		return nil, fmt.Errorf("unknown adapter: %s", conn.GetAdapterType())
 	}
