@@ -14,6 +14,10 @@ type ElasticsearchClient struct {
 	Client *elastic.Client
 }
 
+func (c *ElasticsearchClient) GetClient() *elastic.Client {
+	return c.Client
+}
+
 func New(conn types.ElasticsearchConnection) *ElasticsearchClient {
 	return &ElasticsearchClient{
 		Conn: conn,
