@@ -7,7 +7,6 @@ import (
 
 	"github.com/olivere/elastic/v7"
 	"gitlab.com/gitlab-org/gitlab-elasticsearch-indexer/internal/mode/chunk/chunker"
-	"gitlab.com/gitlab-org/gitlab-elasticsearch-indexer/internal/mode/chunk/client/elasticsearch"
 	"gitlab.com/gitlab-org/gitlab-elasticsearch-indexer/internal/mode/chunk/indexer"
 )
 
@@ -15,6 +14,11 @@ const (
 	DefaultBulkSize = 1000
 )
 
+// Client interface abstracts Elasticsearch and OpenSearch clients
+type Client interface {
+	GetClient() *elastic.Client
+}
+
 // OrphanData holds the data needed for orphan cleanup
 type OrphanData struct {
 	ChunkIDs []string
@@ -22,27 +26,28 @@ type OrphanData struct {
 }
 
 type Indexer struct {
-	esClient   *elasticsearch.ElasticsearchClient
+	client     *elastic.Client
 	indexName  string
 	bulkSize   int
 	bulk       *elastic.BulkService
 	reindexing bool
 }
 
-func New(esClient *elasticsearch.ElasticsearchClient, indexName string, bulkSize int, reindexing bool) (*Indexer, error) {
+func New(client Client, indexName string, bulkSize int, reindexing bool) (*Indexer, error) {
 	if bulkSize <= 0 {
 		bulkSize = DefaultBulkSize
 	}
 
-	if esClient.Client == nil {
-		return nil, fmt.Errorf("elasticsearch client not connected")
+	elasticClient := client.GetClient()
+	if elasticClient == nil {
+		return nil, fmt.Errorf("client not connected")
 	}
 
 	return &Indexer{
-		esClient:   esClient,
+		client:     elasticClient,
 		indexName:  indexName,
 		bulkSize:   bulkSize,
-		bulk:       esClient.Client.Bulk().Index(indexName),
+		bulk:       elasticClient.Bulk().Index(indexName),
 		reindexing: reindexing,
 	}, nil
 }
@@ -66,7 +71,7 @@ func (i *Indexer) Index(ctx context.Context, projectID uint64, chunks []chunker.
 	for _, chunk := range chunks {
 		doc := indexer.BuildChunkDocument(chunk, projectID, i.reindexing)
 
-		// Note: Paths may contain duplicates, but Elasticsearch's terms query handles this efficiently
+		// Note: Paths may contain duplicates, but the terms query handles this efficiently
 		orphanData.Paths = append(orphanData.Paths, chunk.Path)
 		orphanData.ChunkIDs = append(orphanData.ChunkIDs, doc.ID)
 
@@ -128,7 +133,7 @@ func (i *Indexer) deleteOrphanedChunks(ctx context.Context, projectID uint64, da
 			elastic.NewIdsQuery().Ids(data.ChunkIDs...),
 		)
 
-	result, err := i.esClient.Client.DeleteByQuery().
+	result, err := i.client.DeleteByQuery().
 		Index(i.indexName).
 		Query(query).
 		Do(ctx)
@@ -159,7 +164,7 @@ func (i *Indexer) DeletePaths(ctx context.Context, projectID uint64, paths []str
 			elastic.NewTermsQuery("path", pathInterfaces...),
 		)
 
-	result, err := i.esClient.Client.DeleteByQuery().
+	result, err := i.client.DeleteByQuery().
 		Index(i.indexName).
 		Query(query).
 		Do(ctx)
@@ -176,7 +181,7 @@ func (i *Indexer) DeletePaths(ctx context.Context, projectID uint64, paths []str
 func (i *Indexer) Delete(ctx context.Context, projectID uint64) error {
 	query := elastic.NewTermQuery("project_id", projectID)
 
-	result, err := i.esClient.Client.DeleteByQuery().
+	result, err := i.client.DeleteByQuery().
 		Index(i.indexName).
 		Query(query).
 		Routing(fmt.Sprintf("%d", projectID)).
@@ -204,7 +209,7 @@ func (i *Indexer) ResolveReindexing(ctx context.Context, projectID uint64) error
 
 	slog.Debug("resolve_reindexing refreshing index before delete")
 
-	_, err := i.esClient.Client.Refresh(i.indexName).Do(ctx)
+	_, err := i.client.Refresh(i.indexName).Do(ctx)
 	if err != nil {
 		return fmt.Errorf("failed to refresh index: %w", err)
 	}
@@ -219,7 +224,7 @@ func (i *Indexer) ResolveReindexing(ctx context.Context, projectID uint64) error
 			elastic.NewTermsQuery("reindexing", false),
 		)
 
-	deleteResponse, err := i.esClient.Client.DeleteByQuery().
+	deleteResponse, err := i.client.DeleteByQuery().
 		Index(i.indexName).
 		Query(deleteQuery).
 		Routing(fmt.Sprintf("%d", projectID)).
@@ -252,7 +257,7 @@ func (i *Indexer) ResolveReindexing(ctx context.Context, projectID uint64) error
 	updateQuery := elastic.NewTermQuery("project_id", projectID)
 	updateScript := elastic.NewScript("ctx._source.reindexing = false;").Lang("painless")
 
-	updateResponse, err := i.esClient.Client.UpdateByQuery().
+	updateResponse, err := i.client.UpdateByQuery().
 		Index(i.indexName).
 		Query(updateQuery).
 		Routing(fmt.Sprintf("%d", projectID)).
@@ -305,7 +310,7 @@ func (i *Indexer) Flush(ctx context.Context) ([]string, error) {
 	}
 
 	// Reset bulk for next batch
-	i.bulk = i.esClient.Client.Bulk().Index(i.indexName)
+	i.bulk = i.client.Bulk().Index(i.indexName)
 
 	return successfulIDs, nil
 }
